<?php


namespace Drp\SimpleCms\Contracts;

/**
 * Interface IsManaged
 * @package Drp\SimpleCms
 */
interface IsManaged
{
    /**
     * Return a closure that will be called when submitting a ContentRequest.
     * This will allow the Managed class to perform its own action on the
     * request when being used in with the ContentManager.
     *
     * @return null|\Closure
     */
    public function getCallbackForUpdateRequest();

    /**
     * Return the content label based on type.
     *
     * @param boolean $plural Should the label be pluralized
     * @param boolean $lowerCase Should the string be all lowercase
     * @return string
     * @SuppressWarnings(PHPMD.BooleanArgumentFlag)
     */
    public static function contentLabel($plural = false, $lowerCase = false);

    /**
     * Return the label key used to identify the content type.
     * @see config/simple_cms/content_types
     * @return string
     */
    public static function contentKey();

    /**
     * Return the name of the contents relationship based on the Key
     * i.e news-article becomes newsArticle
     *
     * @return string
     */
    public static function relationshipName();

    /**
     * Return and array of the parameters used to build the admin management links.
     *
     * @return array
     */
    public function getContentRouteParameters();

    /**
     * Return and array of the parameters used to access a particular version of the content.
     *
     * @return array
     */
    public function getVersionRouteParameters();

    /**
     * Return the url to edit a content.
     *
     * @return string
     */
    public function adminEditUrl();

    /**
     * Return the url to view the content.
     *
     * @return mixed
     */
    public function frontEndUrl();

    /**
     * Delete all version for the current content.
     *
     * @return integer
     */
    public function destroyAllVersion();
}
