<?php

namespace Drp\SimpleCms\Generators;

use Illuminate\Filesystem\Filesystem;
use Illuminate\Support\Str;

class ViewCreator
{
    /**
     * The filesystem instance.
     *
     * @var \Illuminate\Filesystem\Filesystem
     */
    protected $files;

    /**
     * Create a new migration creator instance.
     *
     * @param  \Illuminate\Filesystem\Filesystem $files
     * @return void
     */
    public function __construct(Filesystem $files)
    {
        $this->files = $files;
    }

    /**
     * Create a new view at the given path.
     *
     * @param  string $path
     * @return void
     */
    public function create($path)
    {
        $this->makeDirectory($path);

        foreach ($this->getStubs() as $stubName => $stub) {
            $this->files->put(
                $this->getPath($stubName, $path),
                $stub
            );
        }
    }

    /**
     * Get the view stub files.
     *
     * @return array
     * @SuppressWarnings(unused)
     */
    protected function getStubs()
    {
        return [
            'create-form-fields' => $this->files->get($this->stubPath() . '/create-form-fields.stub'),
            'form-fields' => $this->files->get($this->stubPath() . '/form-fields.stub')
        ];
    }

    /**
     * Get the full path to the views.
     *
     * @param  string $name
     * @param  string $path
     * @return string
     */
    protected function getPath($name, $path)
    {
        return $path . DIRECTORY_SEPARATOR . $name . '.blade.php';
    }

    /**
     * Get the path to the stubs.
     *
     * @return string
     */
    public function stubPath()
    {
        return __DIR__ . DIRECTORY_SEPARATOR . 'stubs';
    }

    /**
     * Get the class name of a migration name.
     *
     * @param  string $name
     * @return string
     */
    protected function getClassName($name)
    {
        return Str::studly($name);
    }

    /**
     * Make the view directory.
     *
     * @param string $path
     * @return void
     */
    protected function makeDirectory($path)
    {
        if (!$this->files->isDirectory($path)) {
            $this->files->makeDirectory($path, 0755, true);
        }
    }
}
