<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\Contracts\ContentFactory;
use Illuminate\Routing\Controller;

/**
 * Class PreviewController
 * @package Drp\SimpleCms
 */
class PreviewController extends Controller
{
    /**
     * @var \Drp\SimpleCms\ContentFactory
     */
    private $contentFactory;

    /**
     * @param \Drp\SimpleCms\Contracts\ContentFactory $contentFactory
     */
    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }

//  TODO: Add in preview sending / preview listing
//
//    /**
//     * @return \Illuminate\View\View
//     */
//    public function index()
//    {
//        $previews = request()->user()->previews;
//
//        return view('admin.previews.index', compact('previews'));
//    }

    /**
     * Enable preview mode.
     *
     * @param string|null $versionId
     * @param string|null $contentType
     * @return \Illuminate\Http\RedirectResponse
     */
    public function enable($versionId = null, $contentType = null)
    {
        $url = route(config('simple_cms.home_route'));


        if (!is_null($versionId) && !is_null($contentType)) {
            $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);
            $url = $content->frontEndUrl();

            if ($content->isPublished()) {
                session()->flash(
                    'expiredPreviewLink',
                    trans('simpleCms::preview.already_published')
                );
            }
        }

        session([
            'previewMode' => true,
            'previewModeRedirectUrl' => $this->getPreviousUrl(),
        ]);

        return redirect($url);
    }

    /**
     * Disable preview mode.
     *
     * @return \Illuminate\Http\RedirectResponse
     */
    public function disable()
    {
        session()->forget('previewMode');

        $redirectTo = session()->pull('previewModeRedirectUrl');

        if (empty($redirectTo)) {
            return redirect()->route(config('simple_cms.admin_route'));
        }

        return redirect($redirectTo);
    }

    /**
     * Returns the previous url or defaults to the admin dashboard.
     *
     * @return string
     */
    private function getPreviousUrl()
    {
        if ($this->cameFromSite()) {
            return redirect()
                ->getUrlGenerator()
                ->previous(route(config('simple_cms.admin_route')));
        }

        return route(config('simple_cms.admin_route'));
    }

    /**
     * Determine whether the user came from the site.
     *
     * @return boolean
     */
    private function cameFromSite()
    {
        $parsed = parse_url(url()->previous());
        return request()->root() === $parsed['scheme'] . '://' . $parsed['host'];
    }
}
