<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Contracts\ValidatesOnPublish;
use Drp\SimpleCms\Validator;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Routing\Controller;

/**
 * Class PublishController
 * @package Drp\SimpleCms
 */
class PublishController extends Controller
{

    use AuthorizesRequests;

    /**
     * @var \Drp\SimpleCms\ContentFactory;
     */
    private $contentFactory;

    /**
     * PublishController constructor.
     * @param ContentFactory $contentFactory
     */
    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }


    /**
     * @param Validator $validator
     * @param string $contentType
     * @param integer $versionId
     * @return \Illuminate\Http\RedirectResponse
     */
    public function __invoke(Validator $validator, $contentType, $versionId)
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        $this->authorize('publish', $content);

        if ($content instanceof ValidatesOnPublish && !$content->isPublished()) {
            $validator->validateContent($content);
        }


        $content->updatePublishStatus();
        flash()->success(
            trans('simpleCms::content.' . ($content->isPublished() ? 'published' : 'unpublished'))
        );

        return redirect()->back();
    }
}
