<?php

namespace Drp\SimpleCms;

use Drp\SimpleCms\Contracts\Publishable;
use Drp\SimpleCms\Scopes\PreviewScope;
use Drp\SimpleCms\Scopes\PublishedScope;
use Illuminate\Database\Eloquent\Builder;

/**
 * Class Previewer
 * @package Drp\SimpleCms
 */
trait Previewer
{
    /**
     * Get all versions of the Content.
     * This will remove any scopes to ensure we are seeing all versions.
     *
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function allVersionsOfContent()
    {
        return $this->hasMany(static::class, 'content_id', 'content_id')
            ->withoutGlobalScopes([
                PreviewScope::class,
                PublishedScope::class,
            ]);
    }

    /**
     * Scope query to only return Content that does not have Draft/Review content.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeHasNoDraftOrInReview(Builder $query)
    {
        return $query->whereDoesntHave('allVersionsOfContent', function ($query) {
            $query->where('status', Publishable::STATUS_DRAFT)
                ->orWhere('status', Publishable::STATUS_REVIEW);
        });
    }
}
