<?php

namespace Drp\SimpleCms\ViewComposers;

use Illuminate\View\View;

/**
 * Class PreviewModeComposer
 * @package Drp\SimpleCms
 */
class PreviewModeComposer
{
    /**
     * Bind data to the view.
     *
     * @param \Illuminate\View\View $view
     * @return void
     */
    public function compose(View $view)
    {
        $view->with('contentInPreview', $this->contentInPreview($view))
            ->with('userCanEdit', auth()->user()->hasPublishAccess());
    }

    /**
     * Return the Studies that are present in the view data.
     *
     * @param \Illuminate\View\View $view
     * @return \Illuminate\Support\Collection
     * @SuppressWarnings("unused")
     */
    protected function getContent(View $view)
    {
        $contentTypes = collect(config('simple_cms.content_types'))
            ->map(function ($class, $key) {
                return camel_case($key);
            })->flip();

        return collect($view->getData())
            ->intersectKey($contentTypes);
    }

    /**
     * Return the Studies that are available to be previewed.
     *
     * @param \Illuminate\View\View $view
     * @return \Illuminate\Support\Collection
     */
    protected function contentInPreview(View $view)
    {
        $urlKey = $this->getKeyFromUrl();

        return $this->getContent($view)
            ->flatten()
            ->filter()
            ->filter(function ($item) use ($view, $urlKey) {
                return $item->isDraftOrInReview($urlKey);
            });
    }

    /**
     * Return the correct study key from the url.
     * If the url segment is not a study key then look in the mappings config.
     * If the url segment is still not found then this is the nameplate home page.
     *
     * @return mixed|string
     */
    private function getKeyFromUrl()
    {
        $urlKey = collect(request()->segments())->last();

        return str_replace('-', '_', $urlKey);
    }
}
